#
# spec file for package flnet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flnet
Version:        7.5.0
Release:        2.21
Summary:        Voice net controller database/check-in application
License:        GPL-2.0
Group:          Productivity/Hamradio/Other
URL:            http://www.w1hkj.com/
#Git-Clone:     https://git.code.sf.net/p/fldigi/flnet
Source:         http://sourceforge.net/projects/fldigi/files/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fltk-devel
BuildRequires:  flxmlrpc-devel
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
Flnet provides the Amateur Radio Net Control Station operator with a real time
tool to assist him or her in managing the net activities. A single dialog with
multiple panels is used to allow rapid entry, search, pick and display of all
stations calling in to the net.

%prep
%setup -q

%build
export BUILD_DATE=`date -d@0`
export BUILD_USER=openSUSE
export BUILD_HOST=openSUSE
%configure
%make_build

%install
%make_install

%suse_update_desktop_file -i flnet

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/flnet
%{_datadir}/applications/flnet.desktop
%{_datadir}/pixmaps/flnet.xpm

%changelog
* Thu Jun 29 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fix build for Tumbleweed and Factory
- New specfile based on fldigi specflie
* Tue Feb  8 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 7.5.0
  * editor: change input control positions
  * nucall: change txtInfo display for unknown call checkin based
    on whether or not the editor is opened
  * hamcall:
  - corrected hamcall.net account access
  - added city query
  * changes to logins report format:
  - allow user to select which fields are included in the report
  - add header row
  - allow user to select the column order in logins report
  - output is tab delimited for importing into a spreadsheet program
  - change tab delimited output log file extension to .csv
  - add space filled output log file with extension .txt
  * Add database fields for COUNTY, TRAFFIC
  * Add XmlRpc Client ID
  * fix Warnings & Errors exposed by gcc 11.1.1
  * additional logic for keybounce suppression
* Wed Mar 31 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 7.4.0
  * changes required for mxe 32/64 bit builds
  * Update flnet user manual to 7.4.0
  * Like-to-haves
  - Editor: changing the sort order via the Menu Sort, the current
    record will still be displayed in the proper location within
    the new sort.
  - Enter key selects the entered record in the Editor Search dialogs.
  - Enter key selects the selected record in Call/Netnbr browser
  - alt-E will open Editor to the current callin and maintain the
    last used sort order
  - alt-P will toggle the select order (main dialog)
  - force alt events not handled by main dialog to be handled by editor
    (should avoid necessity to cursor over for some window managers)
  - update entire callin list whenever Edit dialog update button is
    invoked.
  * Exit / Priority
  - add fl_choice dialog to exit process
  - remove unused fluid (.fl) files
  - resort after changing database record
    . necessary to allow user to edit callsign of
    visible editor record
  - edit dialog menu follow alt-E / F12 access
  - change to priority resolution at startup
  * Callsign usage
  - change database and entries to comply with international agreements:
    . 1 to 3 character prefix consisting of alphanumeric
    . single character area, a numeric
    . 1 to 3 character suffix containing alphanumeric
  - remove prefix and suffix modifiers
    . DL/...
    ... /M /AM /MM /1 /2 ... /9 etc are all point of transmission
    modifiers and not an actual part of the government assigned
    call.
    . suppress invalid calls
  - deactivate menu items Search, Browse and Sort when in editor in
    MODIFY state (F12)
  * focus
  - insure focus returns to main dialog after a delete
    from the call-in list
  - set inpNickname->take_focus() when editor is opened
  - add F11 with same functionality as shift-F12
  * Callin list index
  - display index number of current "is up" entry
  - deprecate IsInDB search function, use csvdb method find_callsign
  - Use prefix/area/suffix control values for all Queue processing
  * Netedit Queue: fix queue/sorted-by selection
  * Netedit sorts: match display to sortby selection
  * modify debounce logic for correct operation on various
    operating systems.  Not all X are created equal!
  * use fl_width to size logins browser colums
  * Change to PAS sort order wfor callsign searches
  * fix Apple Cmd-Q exit processing
  * csvdb mods
  - change saved sort order to CALL
  - add find_netnbr
  - add find_callsign
  * Edit mods
  - clear filename / record count on Edit dialog before
    assigning new data
  - set State/Province field to auto caps
  - fix sh-F12 data retrieval from fldigi
  - fix F5...F8 priority modification
  - add alt-E/C/Z/I menu short-cuts
  - pass all other alt-key combinations to child dialogs
  - correct operation of 'Update' button for case where
    current record is or is not in the call-in list.
  - adding record to masterdb, if record exists
    . allow either replace, add, or cancel operation
  - close masterdb if pathname changes
  - add user customizable field transfers between active
    and master database
  * UP/DN repeat
  * fix mkappbundle.sh
  * Editor
  - set keyboard focus to editor dialog when opened
  - Always show ST/PR in upper case
  - Leave editor dialog open after update to a record
  - Fix Queue transfer of editor data to call-in list
  * Import/Export fldigi data
  - inhibit opening the master database concurrent with
    it's use for lookups
    . provide warning dialog when user attempts to do so
  - correct data import from fldigi
    . fix data transfer indexing
    . add record to the net database with fields set using
    data imported from fldigi
  - CALL
  - NAME
  - QTH
  - STATE
  - fix Fl_Enter event after Deleting a callin entry causing
    transfer of next callin to fldigi
  - restore keyboard focus to main dialog when closing
    . delete alert
    . editor dialog
    . config dialog
  * Add missing data transfer of netnbr from masterdb
  * add missing callbacks to configuration items
  * Correct csvdb sort algorithm for possible sort list corruption
    . size of suffix string copy set to field size.
    . corrected to 1 less than field size.
  * update buildmxe.sh script
  * replace Fl_Input widgets with Fl_Input2 extended class
  * Editor UI
  - Reorder browse list after deleting a record
  - Add prefix/area/suffix sort order to list
    . prefix/area/suffix
    . area/prefix/suffix
    . suffix/area/prefix
    . net number
  - Add user configurable preferred sort order when
    opening editor
  - Handle special case for empty database and when
    deleting record in db with a single record
  - reflect editorial changes to PREFIX, AREA, SUFFIX to
    all call-in list entries
  - always update callin-list info panel when closing edit dialog
  - save current database / checkin log when opening a new db
  - add file backup to all opened csv database files
    . current plus two aged backups
    <fname>.csv, <fname>.csv.1, <fname>.csv.2
  - add user configurable transfer to/from master db net nbr
  - fix prioritization of checkins
  * Add ability to work with a local master flnet compatible csv file
    . query the file for call details
    . add current record to the master file
  * check-in-list
  - allow user to specifiy left/right justification of callsign field
  - arrange/size "Check-ins" and database name/size displays to
    allow for larger filenames.
  - fix segmentation fault caused by closing Editor under specific
    conditions.
  - fix close down segmentation fault
  - Change to update prevdate only when program is shutting down
  - Check database for match if SUFFIX, PREFIX & AREA are all entered
    . Select match if found; new CALL otherwise
    .  Select 'picked' entry if only SUFFIX entered
  - Display NOT IN DATABASE if call-in entry is not in database
  - Correct button access in Editor when opened by menu Editor
  - Change displayed "Last login" to LoginDate vice PrevDate
  - Repair broken CALL / NETNBR searches
  - Add clearing of email field to all remote db queries
  - Correct Edtor button states after selecting "New"
  - Update CALL whenever Prefix, Area, or Suffix is changed
    . convert Prefix, Area, Suffix to uppercase
  - Change temporary dbSelectLabel from string to char[]
  - Do not add new callin to database until user presses F12
    . delay updating Login date until file closure
    . delay updating joined date pending control operator manual entry
  - Correct net number search algorithm
  - Change all search calls to use binary search algorithm
  - Prevent user from adding an empty record to the database
    . i.e. no Prefix, Area, Suffix triad entered
  * HamQTH queries
  - extract email
  - convert lat/lon to 6 place Maidenhead locator if
    lat/lon present in response
  * Fix color coding for callin list entries
  * Write Log
  - write log after every change to log-in list
  - add hours, minutes to file name
  * Optimizer
  - fix compiler optimizer differences when mixing
    strings with returned char pointers.
  * Callook lookup
  - Fix access and parsing of callook.info query
  - Fix locator to azimuth/distance display
  * UI mods
  - Enable keypad Enter key for selecting call from pick list
  - Fix controlling order on edit dialog
  * added COUNTRY, LOCATOR
  * User configurable distance display, kilometers, nautical miles,
    statute miles.
  * UI fixes
  - change all configuration items to progStatus
  - increase width of check-ins display lines
  - adjust UI widgets, position and size
  - change arrangement of fields in info panel
  - concatenate comment1, comment2 data fields
    separating each with a semicolon.
  - add user configurable justification, left/right for
    nickname field in check-in list
  * modify 'version' to include VERSION_PATCH
  * Keyboard Shortcuts
  - Remove &menu items
  - Enable alt-F4 - cleanExit
* Sun Oct 27 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 7.3.3
- Maintenance release
  * prefs file containing mainX, mainY & ui_size
  * restore saved state main dialog position / size
  * add hamcall query interface
  * add secure network access support
  * remove qrzlib search from program
  * change flxmlrpc configure summary report
* Tue Dec 13 2016 dl8fcl@darc.de
- update to version 7.3.2
* Mon Nov  7 2016 dl8fcl@t-online.de
- update to version 7.3.1
* Sat Apr 30 2016 dl8fcl@t-online.de
- update to version 7.2.5
* Tue Apr 28 2015 dl8fcl@darc.de
- update to version 7.2.3
  requires libflxmlrpc
* Wed Mar 11 2015 dl8fcl@darc.de
- update to versin 7.2.2
  * Fix bug associated with deleting a duplicate record
  * Fix bug in new check-in csv data line
  * Amended Doxyfile(s) for version 7.2.x
* Tue Jul  1 2014 dl8fcl@darc.de
- update to versin 7.2.1
* Tue Feb  4 2014 dl8fcl@darc.de
- update to versin 7.0.1
* Wed Dec 11 2013 dl8fcl@darc.de
- update to versin 7.0.0
* Tue Sep 24 2013 dl8fcl@darc.de
- import into build service
